searchNodes=[{"ref":"FeatureFlag.html","title":"FeatureFlag","type":"module","doc":"FeatureFlag provides a macro that allows for conditional branching at the function level via configuration values. In other words, you can change what a function does at runtime by setting/modifying a config value. Use Case The goal of this library was to provide an elegant and consistent mechanism for changing what a function does depending on a value that can easily be modified (i.e. a configuration value). This could very easily be done in plain Elixir via a simple case statement: defmodule MyApp do def math(x, y) do case Application.fetch_env!(:my_app, :math) do :add -&gt; x + y :multiply -&gt; x * y :subtract x - y end end end There&#39;s nothing wrong with this approach, and really no need to reach for anything else. However, the same code can be rewritten as such using FeatureFlag defmodule MyApp do def math(x, y), feature_flag do :add -&gt; x + y :multiply -&gt; x * y :subtract x - y end end When called, each case will attempt to match on the current value of Application.fetch_env!(:feature_flag, {MyApp, :math, 2}). Beyond removing a marginal amount of code, FeatureFlag provides a consistent interface for defining functions with config-based branching."},{"ref":"FeatureFlag.html#def/3","title":"FeatureFlag.def/3","type":"macro","doc":"A custom version of def that will wrap the function in the approriate conditional logic. Note: You must call Use FeatureFlag in a module before using this macro. Example defmodule MyApp do def math(x, y), feature_flag do :add -&gt; x + y :multiply -&gt; x * y :subtract x - y end end To have this function perform the :multiply procedure, you&#39;d set the feature flag config value like so: config FeatureFlag, {MyApp, :math, 2}, :multiply Or you can use FeatureFlag.set/2 FeatureFlag.set({MyApp, :math, 2}, :multiply)"},{"ref":"FeatureFlag.html#get/1","title":"FeatureFlag.get/1","type":"function","doc":"Returns the current feature flag value for the given function."},{"ref":"FeatureFlag.html#set/2","title":"FeatureFlag.set/2","type":"function","doc":"Sets feature flag value for the given function."},{"ref":"FeatureFlag.MatchError.html","title":"FeatureFlag.MatchError","type":"exception","doc":""},{"ref":"FeatureFlag.MatchError.html#expecting_message/2","title":"FeatureFlag.MatchError.expecting_message/2","type":"function","doc":""},{"ref":"FeatureFlag.MatchError.html#new/4","title":"FeatureFlag.MatchError.new/4","type":"function","doc":""}]